==> google_cloud_notebooks-0.1.1-py2.py3-none-any.whl: google/cloud/notebooks_v1beta1/types/__init__.py <==
# -*- coding: utf-8 -*-

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from .environment import (
    Environment,
    VmImage,
    ContainerImage,
)
from .instance import Instance
from .service import (
    OperationMetadata,
    ListInstancesRequest,
    ListInstancesResponse,
    GetInstanceRequest,
    CreateInstanceRequest,
    RegisterInstanceRequest,
    SetInstanceAcceleratorRequest,
    SetInstanceMachineTypeRequest,
    SetInstanceLabelsRequest,
    DeleteInstanceRequest,
    StartInstanceRequest,
    StopInstanceRequest,
    ResetInstanceRequest,
    ReportInstanceInfoRequest,
    IsInstanceUpgradeableRequest,
    IsInstanceUpgradeableResponse,
    UpgradeInstanceRequest,
    UpgradeInstanceInternalRequest,
    ListEnvironmentsRequest,
    ListEnvironmentsResponse,
    GetEnvironmentRequest,
    CreateEnvironmentRequest,
    DeleteEnvironmentRequest,
)


__all__ = (
    "Environment",
    "VmImage",
    "ContainerImage",
    "Instance",
    "OperationMetadata",
    "ListInstancesRequest",
    "ListInstancesResponse",
    "GetInstanceRequest",
    "CreateInstanceRequest",
    "RegisterInstanceRequest",
    "SetInstanceAcceleratorRequest",
    "SetInstanceMachineTypeRequest",
    "SetInstanceLabelsRequest",
    "DeleteInstanceRequest",
    "StartInstanceRequest",
    "StopInstanceRequest",
    "ResetInstanceRequest",
    "ReportInstanceInfoRequest",
    "IsInstanceUpgradeableRequest",
    "IsInstanceUpgradeableResponse",
    "UpgradeInstanceRequest",
    "UpgradeInstanceInternalRequest",
    "ListEnvironmentsRequest",
    "ListEnvironmentsResponse",
    "GetEnvironmentRequest",
    "CreateEnvironmentRequest",
    "DeleteEnvironmentRequest",
)

==> google_cloud_notebooks-1.3.2-py2.py3-none-any.whl: google/cloud/notebooks_v1beta1/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .environment import ContainerImage, Environment, VmImage
from .instance import Instance
from .service import (
    CreateEnvironmentRequest,
    CreateInstanceRequest,
    DeleteEnvironmentRequest,
    DeleteInstanceRequest,
    GetEnvironmentRequest,
    GetInstanceRequest,
    IsInstanceUpgradeableRequest,
    IsInstanceUpgradeableResponse,
    ListEnvironmentsRequest,
    ListEnvironmentsResponse,
    ListInstancesRequest,
    ListInstancesResponse,
    OperationMetadata,
    RegisterInstanceRequest,
    ReportInstanceInfoRequest,
    ResetInstanceRequest,
    SetInstanceAcceleratorRequest,
    SetInstanceLabelsRequest,
    SetInstanceMachineTypeRequest,
    StartInstanceRequest,
    StopInstanceRequest,
    UpgradeInstanceInternalRequest,
    UpgradeInstanceRequest,
)

__all__ = (
    "ContainerImage",
    "Environment",
    "VmImage",
    "Instance",
    "CreateEnvironmentRequest",
    "CreateInstanceRequest",
    "DeleteEnvironmentRequest",
    "DeleteInstanceRequest",
    "GetEnvironmentRequest",
    "GetInstanceRequest",
    "IsInstanceUpgradeableRequest",
    "IsInstanceUpgradeableResponse",
    "ListEnvironmentsRequest",
    "ListEnvironmentsResponse",
    "ListInstancesRequest",
    "ListInstancesResponse",
    "OperationMetadata",
    "RegisterInstanceRequest",
    "ReportInstanceInfoRequest",
    "ResetInstanceRequest",
    "SetInstanceAcceleratorRequest",
    "SetInstanceLabelsRequest",
    "SetInstanceMachineTypeRequest",
    "StartInstanceRequest",
    "StopInstanceRequest",
    "UpgradeInstanceInternalRequest",
    "UpgradeInstanceRequest",
)
